@@ -1,5 +1,9 @@
+
+# REDUNDANT cat("CANNOT TEST LGCPMETHODS ...\n")
+
 library(lgcp)
 library(spatstat)
+library(spatstat.utils)
 library(sp)
 library(raster)
 
@@ -25,7 +29,7 @@ lgm <- lgcpPredictSpatial(  sd=sd,
                             model.parameters=lgcppars(sigma=2,phi=0.1),
         					spatial.covmodel="exponential",
         					cellwidth=0.1,
-        					spatial.intensity=density(sd),				
+        					spatial.intensity=density(sd),
         					mcmc.control=mcmcpars(mala.length=200,burnin=20,
                                 retain=20,adaptivescheme=andrieuthomsh(inith=1,alpha=0.5,C=1,
                                 targetacceptance=0.574)),
@@ -42,12 +46,12 @@ lg <- lgcpPredict(  xyt=xyt,
 				    spatial.covmodel="exponential",
 				    cellwidth=0.1,
 				    spatial.intensity=density(xyt),
-				    temporal.intensity=function(x){return(100)},					
+				    temporal.intensity=function(x){return(100)},
 				    mcmc.control=mcmcpars(mala.length=200,burnin=20,
 				        retain=20,adaptivescheme=andrieuthomsh(inith=0.01,alpha=0.5,C=1,targetacceptance=0.574)),
 				    output.control=setoutput(gridfunction=
 				                dump2dir(dirname=xytsave,forceSave=TRUE),
-                                gridmeans=MonteCarloAverage("exceed")),	
+                                gridmeans=MonteCarloAverage("exceed")),
 				    autorotate=FALSE,
 				    gradtrunc=Inf)
 
@@ -69,13 +73,13 @@ intens(lgm)
 intens(lg)
 
 seintens(lgm)
-seintens(lg)				    
-				    
-				    
+seintens(lg)
+
+
 # now check conversion
 
 as.array(lgm$y.mean)
-as.array(lg$y.mean)		
+as.array(lg$y.mean)
 
 raster(meanfield(lgm))
 raster(varfield(lg))
@@ -87,10 +91,8 @@ as.SpatialPixelsDataFrame(lgm$y.var)
 
 quantile(lgm,c(0,0.1,0.5))
 quantile(lg,c(0,0.1,0.5))
-			   
+
 t1 <- all.equal(expectation(lgm,function(x){return(x)})[[1]],lgm$y.mean$grid[[1]])
 if(!t1){stop("error in computing expectation in lgcpMethodsTest.R")}
 t2 <- all.equal(expectation(lg,function(x){return(x)})[[1]],lg$y.mean$grid[[length(lg$y.mean$grid)]])
 if(!t2){stop("error in computing expectation in lgcpMethodsTest.R")}
-
-				    
\ No newline at end of file
